Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1026)

Unified Diff: mojo/shell/public/cpp/app_lifetime_helper.h

Issue 1675153002: ApplicationImpl->ShellConnection, mojom::Application->mojom::ShellClient (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@ci2
Patch Set: . Created 4 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « mojo/shell/public/cpp/BUILD.gn ('k') | mojo/shell/public/cpp/application_impl.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: mojo/shell/public/cpp/app_lifetime_helper.h
diff --git a/mojo/shell/public/cpp/app_lifetime_helper.h b/mojo/shell/public/cpp/app_lifetime_helper.h
index ae2503f83fb703c72f3075d1f3f95c15ba01421f..14620b3a95ca89a9d59ee09b86fb6aae3bf13bb3 100644
--- a/mojo/shell/public/cpp/app_lifetime_helper.h
+++ b/mojo/shell/public/cpp/app_lifetime_helper.h
@@ -11,7 +11,7 @@
namespace mojo {
-class ApplicationImpl;
+class ShellConnection;
class AppLifetimeHelper;
// A service implementation should keep this object as a member variable to hold
@@ -54,10 +54,10 @@ class AppRefCount {
// creates an instance of a service, it gives it a refcount using
// CreateAppRefCount. The service implementation then keeps that object as a
// member variable. When all the service implemenations go away, the app will be
// quit with a call to mojo::ApplicationImpl::Terminate().
class AppLifetimeHelper {
public:
- explicit AppLifetimeHelper(ApplicationImpl* app);
+ explicit AppLifetimeHelper(ShellConnection* app);
~AppLifetimeHelper();
scoped_ptr<AppRefCount> CreateAppRefCount();
@@ -67,10 +67,10 @@ class AppLifetimeHelper {
void AddRef();
void Release();
- friend ApplicationImpl;
+ friend ShellConnection;
void OnQuit();
- ApplicationImpl* app_;
+ ShellConnection* app_;
int ref_count_;
DISALLOW_COPY_AND_ASSIGN(AppLifetimeHelper);
« no previous file with comments | « mojo/shell/public/cpp/BUILD.gn ('k') | mojo/shell/public/cpp/application_impl.h » ('j') | no next file with comments »
@@ -54,10 +54,10 @@ class AppRefCount {
// CreateAppRefCount. The service implementation then keeps that object as a
// member variable. When all the service implemenations go away, the app will be
-// quit with a call to mojo::ApplicationImpl::Terminate().
+// quit with a call to mojo::ShellConnection::Terminate().
class AppLifetimeHelper {
public:

Powered by Google App Engine
This is Rietveld 408576698